@@ -1,7 +1,7 @@
 """
 Type annotations for keyspaces service client.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_keyspaces/client.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_keyspaces/client/)
 
 Usage::
 
@@ -70,7 +70,7 @@ class Exceptions:
 class KeyspacesClient(BaseClient):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/keyspaces.html#Keyspaces.Client)
-    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_keyspaces/client.html)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_keyspaces/client/)
     """
 
     meta: ClientMeta
@@ -81,7 +81,7 @@ class KeyspacesClient(BaseClient):
         KeyspacesClient exceptions.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/keyspaces.html#Keyspaces.Client.exceptions)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_keyspaces/client.html#exceptions)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_keyspaces/client/#exceptions)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
@@ -89,7 +89,7 @@ class KeyspacesClient(BaseClient):
         Check if an operation can be paginated.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/keyspaces.html#Keyspaces.Client.can_paginate)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_keyspaces/client.html#can_paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_keyspaces/client/#can_paginate)
         """
 
     def create_keyspace(
@@ -99,7 +99,7 @@ class KeyspacesClient(BaseClient):
         The `CreateKeyspace` operation adds a new keyspace to your account.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/keyspaces.html#Keyspaces.Client.create_keyspace)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_keyspaces/client.html#create_keyspace)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_keyspaces/client/#create_keyspace)
         """
 
     def create_table(
@@ -120,7 +120,7 @@ class KeyspacesClient(BaseClient):
         The `CreateTable` operation adds a new table to the specified keyspace.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/keyspaces.html#Keyspaces.Client.create_table)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_keyspaces/client.html#create_table)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_keyspaces/client/#create_table)
         """
 
     def delete_keyspace(self, *, keyspaceName: str) -> Dict[str, Any]:
@@ -128,7 +128,7 @@ class KeyspacesClient(BaseClient):
         The `DeleteKeyspace` operation deletes a keyspace and all of its tables.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/keyspaces.html#Keyspaces.Client.delete_keyspace)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_keyspaces/client.html#delete_keyspace)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_keyspaces/client/#delete_keyspace)
         """
 
     def delete_table(self, *, keyspaceName: str, tableName: str) -> Dict[str, Any]:
@@ -136,7 +136,7 @@ class KeyspacesClient(BaseClient):
         The `DeleteTable` operation deletes a table and all of its data.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/keyspaces.html#Keyspaces.Client.delete_table)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_keyspaces/client.html#delete_table)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_keyspaces/client/#delete_table)
         """
 
     def generate_presigned_url(
@@ -150,7 +150,7 @@ class KeyspacesClient(BaseClient):
         Generate a presigned url given a client, its method, and arguments.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/keyspaces.html#Keyspaces.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_keyspaces/client.html#generate_presigned_url)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_keyspaces/client/#generate_presigned_url)
         """
 
     def get_keyspace(self, *, keyspaceName: str) -> GetKeyspaceResponseTypeDef:
@@ -158,7 +158,7 @@ class KeyspacesClient(BaseClient):
         Returns the name and the Amazon Resource Name (ARN) of the specified table.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/keyspaces.html#Keyspaces.Client.get_keyspace)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_keyspaces/client.html#get_keyspace)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_keyspaces/client/#get_keyspace)
         """
 
     def get_table(self, *, keyspaceName: str, tableName: str) -> GetTableResponseTypeDef:
@@ -167,7 +167,7 @@ class KeyspacesClient(BaseClient):
         status, the keyspace name, configuration settings, and metadata.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/keyspaces.html#Keyspaces.Client.get_table)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_keyspaces/client.html#get_table)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_keyspaces/client/#get_table)
         """
 
     def list_keyspaces(
@@ -177,7 +177,7 @@ class KeyspacesClient(BaseClient):
         Returns a list of keyspaces.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/keyspaces.html#Keyspaces.Client.list_keyspaces)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_keyspaces/client.html#list_keyspaces)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_keyspaces/client/#list_keyspaces)
         """
 
     def list_tables(
@@ -187,7 +187,7 @@ class KeyspacesClient(BaseClient):
         Returns a list of tables for a specified keyspace.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/keyspaces.html#Keyspaces.Client.list_tables)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_keyspaces/client.html#list_tables)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_keyspaces/client/#list_tables)
         """
 
     def list_tags_for_resource(
@@ -198,7 +198,7 @@ class KeyspacesClient(BaseClient):
         resource.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/keyspaces.html#Keyspaces.Client.list_tags_for_resource)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_keyspaces/client.html#list_tags_for_resource)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_keyspaces/client/#list_tags_for_resource)
         """
 
     def restore_table(
@@ -219,7 +219,7 @@ class KeyspacesClient(BaseClient):
         `earliest_restorable_timestamp` and the current time.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/keyspaces.html#Keyspaces.Client.restore_table)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_keyspaces/client.html#restore_table)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_keyspaces/client/#restore_table)
         """
 
     def tag_resource(self, *, resourceArn: str, tags: Sequence["TagTypeDef"]) -> Dict[str, Any]:
@@ -227,7 +227,7 @@ class KeyspacesClient(BaseClient):
         Associates a set of tags with a Amazon Keyspaces resource.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/keyspaces.html#Keyspaces.Client.tag_resource)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_keyspaces/client.html#tag_resource)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_keyspaces/client/#tag_resource)
         """
 
     def untag_resource(self, *, resourceArn: str, tags: Sequence["TagTypeDef"]) -> Dict[str, Any]:
@@ -235,7 +235,7 @@ class KeyspacesClient(BaseClient):
         Removes the association of tags from a Amazon Keyspaces resource.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/keyspaces.html#Keyspaces.Client.untag_resource)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_keyspaces/client.html#untag_resource)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_keyspaces/client/#untag_resource)
         """
 
     def update_table(
@@ -255,21 +255,21 @@ class KeyspacesClient(BaseClient):
         example capacity mode, encryption, point-in-time recovery, or ttl settings.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/keyspaces.html#Keyspaces.Client.update_table)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_keyspaces/client.html#update_table)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_keyspaces/client/#update_table)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_keyspaces"]) -> ListKeyspacesPaginator:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/keyspaces.html#Keyspaces.Client.get_paginator)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_keyspaces/client.html#get_paginator)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_keyspaces/client/#get_paginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_tables"]) -> ListTablesPaginator:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/keyspaces.html#Keyspaces.Client.get_paginator)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_keyspaces/client.html#get_paginator)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_keyspaces/client/#get_paginator)
         """
 
     @overload
@@ -278,5 +278,5 @@ class KeyspacesClient(BaseClient):
     ) -> ListTagsForResourcePaginator:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/keyspaces.html#Keyspaces.Client.get_paginator)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_keyspaces/client.html#get_paginator)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_keyspaces/client/#get_paginator)
         """
