@@ -1,7 +1,7 @@
 """
 Type annotations for keyspaces service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_keyspaces/literals.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_keyspaces/literals/)
 
 Usage::
 
@@ -85,6 +85,7 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
@@ -171,6 +172,7 @@ ServiceName = Literal[
     "frauddetector",
     "fsx",
     "gamelift",
+    "gamesparks",
     "glacier",
     "globalaccelerator",
     "glue",
